@@ -1,4 +1,5 @@
-from typing import TYPE_CHECKING, Any, Dict, List, Tuple
+# mypy: disable-error-code=empty-body
+from typing import TYPE_CHECKING, Any
 
 # alternative pattern that does not require npe2 at runtime
 if TYPE_CHECKING:
@@ -10,13 +11,11 @@ else:
 
 
 @implements.on_activate
-def activate(ctx):
-    ...
+def activate(ctx): ...
 
 
 @implements.on_deactivate
-def deactivate(ctx):
-    ...
+def deactivate(ctx): ...
 
 
 @implements.reader(
@@ -25,8 +24,7 @@ def deactivate(ctx):
     filename_patterns=["*.fzy", "*.fzzy"],
     accepts_directories=True,
 )
-def get_reader(path: str):
-    ...
+def get_reader(path: str): ...
 
 
 @implements.writer(
@@ -41,5 +39,6 @@ def get_reader(path: str):
     filename_extensions=["*.pcd", "*.e57"],
     layer_types=["points{1}", "surface+"],
 )
-def writer_function(path: str, layer_data: List[Tuple[Any, Dict, str]]) -> List[str]:
-    ...
+def writer_function(
+    path: str, layer_data: list[tuple[Any, dict, str]]
+) -> list[str]: ...
